--- demux_playlist.c	2021-10-17 13:14:39.044577543 +0200
+++ demux_playlist1.c	2021-10-17 14:05:58.260617594 +0200
@@ -50,7 +50,7 @@
 struct pl_parser {
     struct mp_log *log;
     struct stream *s;
-    char buffer[2 * 1024 * 1024];
+    char *buffer;
     int utf16;
     struct playlist *pl;
     bool error;
@@ -109,14 +109,25 @@
 // Otherwise, return the line (including \n or \r\n at the end of the line).
 // If the return value is non-NULL, it's always the same as mem.
 // utf16: 0: UTF8 or 8 bit legacy, 1: UTF16-LE, 2: UTF16-BE
-static char *read_line(stream_t *s, char *mem, int max, int utf16)
+static char *read_line(stream_t *s, char **mem, int max, int utf16)
 {
+    char *tmp;
+
     if (max < 1)
         return NULL;
     int read = 0;
+
+    if (*mem != NULL)
+        free(*mem);
+    *mem = malloc(max + 1);
+    if (*mem == NULL) {
+        MP_WARN(s, "error allocating memory\n");
+        return NULL;
+    }
+
     while (1) {
         // Reserve 1 byte of ptr for terminating \0.
-        int l = read_characters(s, &mem[read], max - read - 1, utf16);
+        int l = read_characters(s, &mem[read], max, utf16);
         if (l < 0 || memchr(&mem[read], '\0', l)) {
             MP_WARN(s, "error reading line\n");
             return NULL;
@@ -124,6 +135,16 @@
         read += l;
         if (l == 0 || (read > 0 && mem[read - 1] == '\n'))
             break;
+
+        tmp = realloc(*mem, read + max + 1);
+        if (tmp == NULL) {
+            free(*mem);
+            *mem = NULL;
+            MP_WARN(s, "error allocating memory\n");
+            return NULL;
+        }
+        *mem = tmp;
+
     }
     mem[read] = '\0';
     if (!stream_read_peek(s, &(char){0}, 1) && read == 0) // legitimate EOF
@@ -133,7 +154,7 @@
 
 static char *pl_get_line0(struct pl_parser *p)
 {
-    char *res = read_line(p->s, p->buffer, sizeof(p->buffer), p->utf16);
+    char *res = read_line(p->s, &p->buffer, 65536, p->utf16);
     if (res) {
         int len = strlen(res);
         if (len > 0 && res[len - 1] == '\n')
@@ -451,6 +472,8 @@
     free_stream(p->s);
     playlist_clear(p->pl);
     if (!fmt) {
+        if (p->buffer != NULL)
+            free(p->buffer);
         talloc_free(p);
         return -1;
     }
@@ -466,6 +489,8 @@
     demuxer->playlist = talloc_steal(demuxer, p->pl);
     demuxer->filetype = p->format ? p->format : fmt->name;
     demuxer->fully_read = true;
+    if (p->buffer != NULL)
+        free(p->buffer);
     talloc_free(p);
     if (ok)
         demux_close_stream(demuxer);
